..
    This file is part of Invenio.
    Copyright (C) 2020 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

.. _upgrading:

Upgrading
---------
Guides on how to upgrade to a specific Invenio version.

.. toctree::
    :maxdepth: 2
    :name: mastertoc

    upgrade-3_2-3_3
    upgrade-3_1-3_2
    upgrade-marshmallow
